bamrd: Reads the BAM file

Description Usage Arguments Value Author(s)

View source: R/bamrd.R

Description

Separates data from the input BAM file into a number of data frames, each suitable for the further RNA editing analysis

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
bamrd(
  bam_file_name,
  reference_fasta,
  max_depth = 8000,
  min_base_quality = 13,
  min_mapq = 30,
  min_nucleotide_depth = 1,
  min_minor_allele_depth = 0,
  min_coverage = 0,
  use_noncanonical = TRUE,
  strand_specific = FALSE,
  single_end = TRUE
)

Arguments

bam_file_name

A character(1) path to the input BAM file

reference_fasta

A character(1) path to the reference genome FASTA file

max_depth

An integer(1) maximum number of nucleotides to be included in pileup

min_base_quality

An integer(1) minimum QUAL value for each nucleotide in an alignment

min_mapq

An integer(1) minimum MAPQ value for an alignment to be included in pileup

min_nucleotide_depth

An integer(1) minimum count of each nucleotide at a given position required for said nucleotide to appear in the result

min_minor_allele_depth

An integer(1) left undocumented

min_coverage

An integer(1) minimum coverage for position to be included in final dataset

use_noncanonical

A logical(1) indicating whether to use (TRUE) all chromosomes from BAM including non-canonical ones'

strand_specific

A logical(1) indicating the presence either of the strand-specific (TRUE) RNA-seq experiment, or non-strand-specific (FALSE) one

single_end

A logical(1) indicating the presence of the single-end (TRUE) RNA-seq experiment

Value

On strand_specific == TRUE the list of three data frames (with names pileup_table, messy_positions, and pairs), otherwise the list of only one data frame (with name pileup_table) suitable for the further RNA editing analysis

Author(s)

Irina Shchyukina


DobzhanskyCenterSPBU/rnaedt documentation built on July 26, 2020, 12:41 p.m.