get_strand: Tries to define correct strand of the position via counting...

Description Usage Author(s)

View source: R/bamrd.R

Description

Tries to define correct strand of the position via counting reads aligned to both strands

Usage

1
2
3
4
5
6
7
get_strand(
  pos_first,
  current_chromosome_length,
  current_chromosome,
  bam_file,
  single_end
)

Author(s)

Irina Shchyukina


DobzhanskyCenterSPBU/rnaedt documentation built on July 26, 2020, 12:41 p.m.