Description Usage Arguments Value Author(s)
Separates data from the input BAM file into a number of data frames, each suitable for the further RNA editing analysis
1 2 3 4 5 6 7 8 9 10 11 12 13 |
bam_file_name |
A |
reference_fasta |
A |
max_depth |
An |
min_base_quality |
An |
min_mapq |
An |
min_nucleotide_depth |
An |
min_minor_allele_depth |
An |
min_coverage |
An |
use_noncanonical |
A |
strand_specific |
A |
single_end |
A |
On strand_specific == TRUE the list of three data frames (with names pileup_table, messy_positions, and pairs), otherwise the list of only one data frame (with name pileup_table) suitable for the further RNA editing analysis
Irina Shchyukina
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.